@@ -1,14 +1,21 @@
-/* szstyp.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     LINE TYPE ATTRIBUTE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szstyp_0_(int n__, integer *itype)
 {
@@ -20,7 +27,7 @@
     static integer idashz = 0;
     static logical lfrst = TRUE_;
 
-    static integer ipat[4], n;
+    static integer n, ipat[4];
     extern /* Subroutine */ int bitpci_(char *, integer *, ftnlen);
     static integer itypez;
     extern /* Subroutine */ int szstyz_(integer *);
